import { View } from '@tarojs/components'
import { Component } from '@tarojs/taro'
import './index.scss'
import { GetShopList, GetShopTypeList } from '@/services/shop'
import ready from '@/utils/ready'
import ShopItem from './item'
import { connect } from '@tarojs/redux'
import ListView from '@/components/ListView'

@connect(
  state => ({ ...state.city })
)
export default class Index extends Component {
  config = {
    navigationBarTitleText: ''
  }
  state = {
    isEmpty: false,
    SearchName: '',
    StoreList: [],
    NavList: [],
    PageNum: 1,
    hasMore: true,
    DataLock: false,
    CurrentTypeId: null,
    CityData: null
  }
  componentWillMount () {
    ready.queue(() => {
      Taro.setNavigationBarTitle({ title: this.$router.params.name })
      const city = this.state.city || this.props.curCity
      this.setState({
        CityData: city
      }, () => {
        GetShopTypeList({ pageNum: 1, pageSize: 10 }).then((res) => {
          let Arr = res.records || []
          let aArr = []
          Arr.map((item) => {
            aArr.push({ id: item.typeId, img: item.thumb, name: item.typeName })
          })
          this.setState({
            NavList: aArr,
            PageNum: 1,
            StoreList: []
          }, () => {
            this.ToGetPageList()
          })
        })
      })
    })
  }
  ToGetPageList () {
    if (!this.state.hasMore || this.DataLock) return
    this.DataLock = true
    GetShopList({ pageNum: this.state.PageNum, pageSize: 10, typeId: this.$router.params.type, sortField: 'sort_no' }).then((res) => {
      let Arr = res.records || []
      let aArr = []
      Arr.map((item) => {
        aArr.push({ ...item, badges: (item.badges || '').split(',') || [], lng: item.lngLat.split(',')[0], lat: item.lngLat.split(',')[1] })
      })
      this.setState({
        hasMore: res.total > this.state.StoreList.length + aArr.length,
        StoreList: this.state.StoreList.concat(aArr || [])
      }, () => {
        this.setState({
          isEmpty: !this.state.StoreList.length
        })
      })
      this.DataLock = false
    })
  }
  onPullDownRefresh = async (rest) => {
    this.setState({
      PageNum: 1,
      StoreList: [],
      hasMore: true
    }, () => {
      this.ToGetPageList()
      rest && rest()
    })
  }
  onScrollToLower = async (fn) => {
    this.setState({
      PageNum: this.state.PageNum + 1
    }, () => {
      this.ToGetPageList()
      fn && fn()
    })
  }
  GoBack () {
    Taro.navigateBack()
  }
  render () {
    const { NavList, StoreList, CityData, hasMore, isEmpty } = this.state
    return (
      <ListView
        className="wrap"
        needInit
        isEmpty={isEmpty}
        emptyText="暂无商家~"
        hasMore={hasMore}
        onPullDownRefresh={fn => this.onPullDownRefresh(fn)}
        onScrollToLower={fn => this.onScrollToLower(fn)}
      >
        <View className='Page'>

          {/* 乐客商家 */}
          <View className='LeKeStore'>
            {
              StoreList.map((item, index) => (
                <View>
                  <View className='Line'></View>
                  <ShopItem item={item} lat={CityData.lat} lng={CityData.lng} key={`Store-${index}`}></ShopItem>
                </View>
              ))
            }
          </View>

        </View>
      </ListView>
    )
  }
}
